widelands-dev team mailing list archive
-
widelands-dev team
-
Mailing list archive
-
Message #04767
[Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
kaputtnik has proposed merging lp:~widelands-dev/widelands/is_value_terms into lp:widelands.
Commit message:
Changing the is values in world/terrains/init.lua and the terms for is-value related things in C++ code.
dead -> unreachable
mountain -> minebale
green -> arable
dry -> walkable
Requested reviews:
Widelands Developers (widelands-dev)
Related bugs:
Bug #1519895 in widelands: "Renaming terms of is_value"
https://bugs.launchpad.net/widelands/+bug/1519895
For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/is_value_terms/+merge/279205
This version change also the strings for the editor_info_tool to reflect the changes and uses the same terms.
All other things that has been discussed works well also.
--
Your team Widelands Developers is requested to review the proposed merge of lp:~widelands-dev/widelands/is_value_terms into lp:widelands.
=== renamed file 'pics/terrain_green.png' => 'pics/terrain_arable.png'
=== modified file 'pics/terrain_impassable.png'
Binary files pics/terrain_impassable.png 2015-02-24 13:51:38 +0000 and pics/terrain_impassable.png 2015-12-01 22:48:37 +0000 differ
=== renamed file 'pics/terrain_mountain.png' => 'pics/terrain_mineable.png'
Binary files pics/terrain_mountain.png 2009-11-09 19:01:11 +0000 and pics/terrain_mineable.png 2015-12-01 22:48:37 +0000 differ
=== renamed file 'pics/terrain_dead.png' => 'pics/terrain_unreachable.png'
=== renamed file 'pics/terrain_dry.png' => 'pics/terrain_walkable.png'
Binary files pics/terrain_dry.png 2009-11-09 19:01:11 +0000 and pics/terrain_walkable.png 2015-12-01 22:48:37 +0000 differ
=== modified file 'pics/terrain_water.png'
Binary files pics/terrain_water.png 2005-12-29 01:10:07 +0000 and pics/terrain_water.png 2015-12-01 22:48:37 +0000 differ
=== modified file 'src/editor/tools/editor_info_tool.cc'
--- src/editor/tools/editor_info_tool.cc 2015-11-27 14:42:11 +0000
+++ src/editor/tools/editor_info_tool.cc 2015-12-01 22:48:37 +0000
@@ -110,25 +110,25 @@
Widelands::TerrainDescription::Type terrain_is = ter.get_is();
std::vector<std::string> terrain_is_strings;
- if (terrain_is == Widelands::TerrainDescription::Type::kGreen) {
+ if (terrain_is == Widelands::TerrainDescription::Type::kArable) {
terrain_is_strings.push_back(_("arable"));
}
- if (terrain_is & Widelands::TerrainDescription::Type::kDry) {
- terrain_is_strings.push_back(_("treeless"));
+ if (terrain_is & Widelands::TerrainDescription::Type::kWalkable) {
+ terrain_is_strings.push_back(_("walkable"));
}
if (terrain_is & Widelands::TerrainDescription::Type::kWater) {
- terrain_is_strings.push_back(_("aquatic"));
- }
- if (terrain_is & Widelands::TerrainDescription::Type::kDead) {
- terrain_is_strings.push_back(_("dead"));
- }
- if (terrain_is & Widelands::TerrainDescription::Type::kMountain) {
- terrain_is_strings.push_back(_("mountainous"));
+ terrain_is_strings.push_back(_("navigable"));
+ }
+ if (terrain_is & Widelands::TerrainDescription::Type::kUnreachable) {
+ terrain_is_strings.push_back(_("unreachable"));
+ }
+ if (terrain_is & Widelands::TerrainDescription::Type::kMineable) {
+ terrain_is_strings.push_back(_("mineable"));
}
if (terrain_is & Widelands::TerrainDescription::Type::kImpassable) {
terrain_is_strings.push_back(_("impassable"));
}
- buf += "• " + (boost::format(_("Category: %s"))
+ buf += "• " + (boost::format(_("Is: %s"))
% i18n::localize_list(terrain_is_strings, i18n::ConcatenateWith::AMPERSAND)).str() + "\n";
buf += "• " + (boost::format(_("Editor Category: %s")) % ter.editor_category().descname()).str() + "\n";
=== modified file 'src/editor/ui_menus/editor_tool_set_terrain_options_menu.cc'
--- src/logic/map.cc 2015-11-18 08:41:27 +0000
+++ src/logic/map.cc 2015-12-01 22:48:37 +0000
@@ -1056,7 +1056,7 @@
// 1b) Collect some information about the neighbours
uint8_t cnt_impassable = 0;
uint8_t cnt_water = 0;
- uint8_t cnt_dead = 0;
+ uint8_t cnt_unreachable = 0;
if (tr_d_terrain_is & TerrainDescription::Type::kImpassable) ++cnt_impassable;
if (tl_r_terrain_is & TerrainDescription::Type::kImpassable) ++cnt_impassable;
@@ -1072,12 +1072,12 @@
if (f_d_terrain_is & TerrainDescription::Type::kWater) ++cnt_water;
if (f_r_terrain_is & TerrainDescription::Type::kWater) ++cnt_water;
- if (tr_d_terrain_is & TerrainDescription::Type::kDead) ++cnt_dead;
- if (tl_r_terrain_is & TerrainDescription::Type::kDead) ++cnt_dead;
- if (tl_d_terrain_is & TerrainDescription::Type::kDead) ++cnt_dead;
- if (l_r_terrain_is & TerrainDescription::Type::kDead) ++cnt_dead;
- if (f_d_terrain_is & TerrainDescription::Type::kDead) ++cnt_dead;
- if (f_r_terrain_is & TerrainDescription::Type::kDead) ++cnt_dead;
+ if (tr_d_terrain_is & TerrainDescription::Type::kUnreachable) ++cnt_unreachable;
+ if (tl_r_terrain_is & TerrainDescription::Type::kUnreachable) ++cnt_unreachable;
+ if (tl_d_terrain_is & TerrainDescription::Type::kUnreachable) ++cnt_unreachable;
+ if (l_r_terrain_is & TerrainDescription::Type::kUnreachable) ++cnt_unreachable;
+ if (f_d_terrain_is & TerrainDescription::Type::kUnreachable) ++cnt_unreachable;
+ if (f_r_terrain_is & TerrainDescription::Type::kUnreachable) ++cnt_unreachable;
// 2) Passability
@@ -1094,7 +1094,7 @@
// 2c) [OVERRIDE] If any of the neighbouring triangles is really "bad" (such
// as lava), we can neither walk nor swim to this node.
- if (cnt_dead)
+ if (cnt_unreachable)
caps &= ~(MOVECAPS_WALK | MOVECAPS_SWIM);
// === everything below is used to check buildability ===
@@ -1281,21 +1281,23 @@
world.terrain_descr (f.field->terrain_r()).get_is()
};
- uint32_t cnt_mountain = 0;
- uint32_t cnt_dry = 0;
+ uint32_t cnt_mineable = 0;
+ uint32_t cnt_walkable = 0;
for (uint32_t i = 0; i < 6; ++i) {
if (terrains[i] & TerrainDescription::Type::kWater)
return BaseImmovable::NONE;
- if (terrains[i] & TerrainDescription::Type::kMountain) ++cnt_mountain;
- if (terrains[i] & TerrainDescription::Type::kDry) ++cnt_dry;
+ if (terrains[i] & TerrainDescription::Type::kImpassable)
+ return BaseImmovable::NONE;
+ if (terrains[i] & TerrainDescription::Type::kMineable) ++cnt_mineable;
+ if (terrains[i] & TerrainDescription::Type::kWalkable) ++cnt_walkable;
}
- if (cnt_mountain == 6) {
+ if (cnt_mineable == 6) {
if (ismine)
*ismine = true;
return BaseImmovable::SMALL;
}
- if (cnt_mountain || cnt_dry)
+ if (cnt_mineable || cnt_walkable)
return BaseImmovable::NONE;
// Adjust size based on neighbouring immovables
=== modified file 'src/logic/worker.cc'
--- src/logic/worker.cc 2015-11-25 08:42:28 +0000
+++ src/logic/worker.cc 2015-12-01 22:48:37 +0000
@@ -2715,11 +2715,11 @@
bool is_center_mountain =
(world.terrain_descr(owner_area.field->terrain_d()).get_is()
&
- TerrainDescription::Type::kMountain)
+ TerrainDescription::Type::kMineable)
|
(world.terrain_descr(owner_area.field->terrain_r()).get_is()
&
- TerrainDescription::Type::kMountain);
+ TerrainDescription::Type::kMineable);
// Only run towards fields that are on a mountain (or not)
// depending on position of center
bool is_target_mountain;
@@ -2732,11 +2732,11 @@
is_target_mountain =
(world.terrain_descr(target.field->terrain_d()).get_is()
&
- TerrainDescription::Type::kMountain)
+ TerrainDescription::Type::kMineable)
|
(world.terrain_descr(target.field->terrain_r()).get_is()
&
- TerrainDescription::Type::kMountain);
+ TerrainDescription::Type::kMineable);
if (i == 0)
i = list.size();
--i;
=== modified file 'src/logic/world/terrain_description.cc'
--- src/logic/world/terrain_description.cc 2015-11-11 09:56:22 +0000
+++ src/logic/world/terrain_description.cc 2015-12-01 22:48:37 +0000
@@ -37,29 +37,25 @@
// Parse a terrain type from the giving string.
TerrainDescription::Type terrain_type_from_string(const std::string& type) {
- if (type == "green") {
- return TerrainDescription::Type::kGreen;
+ if (type == "arable") {
+ return TerrainDescription::Type::kArable;
}
- if (type == "dry") {
- return TerrainDescription::Type::kDry;
+ if (type == "walkable") {
+ return TerrainDescription::Type::kWalkable;
}
if (type == "water") {
return static_cast<TerrainDescription::Type>(TerrainDescription::Type::kWater |
- TerrainDescription::Type::kDry |
- TerrainDescription::Type::kImpassable);
- }
- if (type == "dead") {
- return static_cast<TerrainDescription::Type>(TerrainDescription::Type::kDead |
- TerrainDescription::Type::kDry |
- TerrainDescription::Type::kImpassable);
- }
- if (type == "mountain") {
- return static_cast<TerrainDescription::Type>(TerrainDescription::Type::kDry |
- TerrainDescription::Type::kMountain);
+ TerrainDescription::Type::kImpassable);
+ }
+ if (type == "unreachable") {
+ return static_cast<TerrainDescription::Type>(TerrainDescription::Type::kUnreachable |
+ TerrainDescription::Type::kImpassable);
+ }
+ if (type == "mineable") {
+ return static_cast<TerrainDescription::Type>(TerrainDescription::Type::kMineable);
}
if (type == "impassable") {
- return static_cast<TerrainDescription::Type>(TerrainDescription::Type::kDry |
- TerrainDescription::Type::kImpassable);
+ return static_cast<TerrainDescription::Type>(TerrainDescription::Type::kImpassable);
}
throw LuaError((boost::format("invalid terrain type '%s'") % type).str());
}
=== modified file 'src/logic/world/terrain_description.h'
--- src/logic/world/terrain_description.h 2015-11-11 09:56:22 +0000
+++ src/logic/world/terrain_description.h 2015-12-01 22:48:37 +0000
@@ -43,11 +43,11 @@
class TerrainDescription {
public:
enum Type {
- kGreen = 0,
- kDry = 1,
+ kArable = 0,
+ kWalkable = 1,
kWater = 2,
- kDead = 4,
- kMountain = 8,
+ kUnreachable = 4,
+ kMineable = 8,
kImpassable = 16,
};
=== modified file 'world/terrains/init.lua'
--- world/terrains/init.lua 2015-10-31 12:11:44 +0000
+++ world/terrains/init.lua 2015-12-01 22:48:37 +0000
@@ -40,13 +40,13 @@
-- on.
--- src/editor/ui_menus/editor_tool_set_terrain_options_menu.cc 2015-10-10 11:47:22 +0000
+++ src/editor/ui_menus/editor_tool_set_terrain_options_menu.cc 2015-12-01 22:48:37 +0000
@@ -43,25 +43,26 @@
using namespace Widelands;
static const int32_t check[] = {
- TerrainDescription::Type::kGreen, // "green"
- TerrainDescription::Type::kDry, // "dry"
- TerrainDescription::Type::kDry | TerrainDescription::Type::kMountain, // "mountain"
- TerrainDescription::Type::kDry | TerrainDescription::Type::kImpassable, // "impassable"
- TerrainDescription::Type::kDead | TerrainDescription::Type::kDry |
- TerrainDescription::Type::kImpassable, // "dead"
- TerrainDescription::Type::kImpassable | TerrainDescription::Type::kDry | TerrainDescription::Type::kWater,
+ TerrainDescription::Type::kArable, // Arable implies walkable
+ TerrainDescription::Type::kWalkable,
+ TerrainDescription::Type::kMineable, // Mountain implies walkable"
+ TerrainDescription::Type::kImpassable,
+ TerrainDescription::Type::kUnreachable | // Unreachable is impassable
+ TerrainDescription::Type::kImpassable,
+ TerrainDescription::Type::kWater | // Water is impassable
+ TerrainDescription::Type::kImpassable,
-1, // end marker
};
UI::Checkbox* create_terrain_checkbox(UI::Panel* parent,
const TerrainDescription& terrain_descr,
std::vector<std::unique_ptr<const Image>>* offscreen_images) {
- const Image* green = g_gr->images().get("pics/terrain_green.png");
+ const Image* arable = g_gr->images().get("pics/terrain_arable.png");
const Image* water = g_gr->images().get("pics/terrain_water.png");
- const Image* mountain = g_gr->images().get("pics/terrain_mountain.png");
- const Image* dead = g_gr->images().get("pics/terrain_dead.png");
+ const Image* mineable = g_gr->images().get("pics/terrain_mineable.png");
+ const Image* unreachable = g_gr->images().get("pics/terrain_unreachable.png");
const Image* impassable = g_gr->images().get("pics/terrain_impassable.png");
- const Image* dry = g_gr->images().get("pics/terrain_dry.png");
+ const Image* walkable = g_gr->images().get("pics/terrain_walkable.png");
constexpr int kSmallPicHeight = 20;
constexpr int kSmallPicWidth = 20;
@@ -82,10 +83,10 @@
BlendMode::UseAlpha, texture);
Point pt(1, terrain_texture.height() - kSmallPicHeight - 1);
- if (ter_is == TerrainDescription::Type::kGreen) {
- blit(Rect(pt.x, pt.y, green->width(), green->height()),
- *green,
- Rect(0, 0, green->width(), green->height()),
+ if (ter_is == TerrainDescription::Type::kArable) {
+ blit(Rect(pt.x, pt.y, arable->width(), arable->height()),
+ *arable,
+ Rect(0, 0, arable->width(), arable->height()),
1.,
BlendMode::UseAlpha,
texture);
@@ -102,29 +103,29 @@
texture);
pt.x += kSmallPicWidth + 1;
/** TRANSLATORS: This is a terrain type tooltip in the editor */
- tooltips.push_back(_("aquatic"));
- }
- else if (ter_is & TerrainDescription::Type::kMountain) {
- blit(Rect(pt.x, pt.y, mountain->width(), mountain->height()),
- *mountain,
- Rect(0, 0, mountain->width(), mountain->height()),
- 1.,
- BlendMode::UseAlpha,
- texture);
- pt.x += kSmallPicWidth + 1;
- /** TRANSLATORS: This is a terrain type tooltip in the editor */
- tooltips.push_back(_("mountainous"));
- }
- if (ter_is & TerrainDescription::Type::kDead) {
- blit(Rect(pt.x, pt.y, dead->width(), dead->height()),
- *dead,
- Rect(0, 0, dead->width(), dead->height()),
- 1.,
- BlendMode::UseAlpha,
- texture);
- pt.x += kSmallPicWidth + 1;
- /** TRANSLATORS: This is a terrain type tooltip in the editor */
- tooltips.push_back(_("dead"));
+ tooltips.push_back(_("navigable"));
+ }
+ else if (ter_is & TerrainDescription::Type::kMineable) {
+ blit(Rect(pt.x, pt.y, mineable->width(), mineable->height()),
+ *mineable,
+ Rect(0, 0, mineable->width(), mineable->height()),
+ 1.,
+ BlendMode::UseAlpha,
+ texture);
+ pt.x += kSmallPicWidth + 1;
+ /** TRANSLATORS: This is a terrain type tooltip in the editor */
+ tooltips.push_back(_("mineable"));
+ }
+ if (ter_is & TerrainDescription::Type::kUnreachable) {
+ blit(Rect(pt.x, pt.y, unreachable->width(), unreachable->height()),
+ *unreachable,
+ Rect(0, 0, unreachable->width(), unreachable->height()),
+ 1.,
+ BlendMode::UseAlpha,
+ texture);
+ pt.x += kSmallPicWidth + 1;
+ /** TRANSLATORS: This is a terrain type tooltip in the editor */
+ tooltips.push_back(_("unreachable"));
}
if (ter_is & TerrainDescription::Type::kImpassable) {
blit(Rect(pt.x, pt.y, impassable->width(), impassable->height()),
@@ -137,15 +138,15 @@
/** TRANSLATORS: This is a terrain type tooltip in the editor */
tooltips.push_back(_("impassable"));
}
- if (ter_is & TerrainDescription::Type::kDry) {
- blit(Rect(pt.x, pt.y, dry->width(), dry->height()),
- *dry,
- Rect(0, 0, dry->width(), dry->height()),
+ if (ter_is & TerrainDescription::Type::kWalkable) {
+ blit(Rect(pt.x, pt.y, walkable->width(), walkable->height()),
+ *walkable,
+ Rect(0, 0, walkable->width(), walkable->height()),
1.,
BlendMode::UseAlpha,
texture);
/** TRANSLATORS: This is a terrain type tooltip in the editor */
- tooltips.push_back(_("treeless"));
+ tooltips.push_back(_("walkable"));
}
}
=== modified file 'src/logic/map.cc'
--
-- The following properties are available:
- -- "green": Allows building of normal buildings and roads
- -- "mountain": Allows building of mines and roads
- -- "dry": Allows building of roads only. Trees don't like this terrain.
+ -- "arable": Allows building of normal buildings and roads
+ -- "mineable": Allows building of mines and roads
+ -- "walkable": Allows building of roads only
-- "water": Nothing can be built here, but ships and aquatic animals can pass
- -- "dead": Nothing can be built here, and nothing can walk on it, and nothing will grow.
+ -- "unreachable": Nothing can be built here (not even immovables), and nothing can walk on it
-- "impassable": Nothing can be built here, and nothing can walk on it
- is = "green",
+ is = "arable",
-- The list resources that can be found in this terrain.
valid_resources = {"water"},
@@ -79,7 +79,7 @@
name = "wiese2",
descname = _ "Meadow",
editor_category = "green",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 10,
@@ -96,7 +96,7 @@
name = "wiese3",
descname = _ "Meadow",
editor_category = "green",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 10,
@@ -112,7 +112,7 @@
name = "wiese4",
descname = _ "Meadow",
editor_category = "green",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 10,
@@ -128,7 +128,7 @@
name = "steppe",
descname = _ "Steppe",
editor_category = "green",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 5,
@@ -144,7 +144,7 @@
name = "steppe_kahl",
descname = _ "Barren Steppe",
editor_category = "green",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 4,
@@ -160,7 +160,7 @@
name = "bergwiese",
descname = _ "Mountain Meadow",
editor_category = "green",
- is = "green",
+ is = "arable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -176,7 +176,7 @@
name = "berg1",
descname = _ "Mountain",
editor_category = "green",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -192,7 +192,7 @@
name = "berg2",
descname = _ "Mountain",
editor_category = "green",
- is = "mountain",
+ is = "mineable",
valid_resources = {"coal", "iron", "gold", "stones"},
default_resource = "",
default_resource_amount = 0,
@@ -208,7 +208,7 @@
name = "berg3",
descname = _ "Mountain",
editor_category = "green",
- is = "mountain",
+ is = "mineable",
valid_resources = {"coal", "iron", "gold", "stones"},
default_resource = "",
default_resource_amount = 0,
@@ -224,7 +224,7 @@
name = "berg4",
descname = _ "Mountain",
editor_category = "green",
- is = "mountain",
+ is = "mineable",
valid_resources = {"coal", "iron", "gold", "stones"},
default_resource = "",
default_resource_amount = 0,
@@ -257,7 +257,7 @@
name = "strand",
descname = _ "Beach",
editor_category = "green",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -271,7 +271,7 @@
name = "schnee",
descname = _ "Snow",
editor_category = "green",
- is = "dead",
+ is = "unreachable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -287,7 +287,7 @@
name = "lava",
descname = _ "Lava",
editor_category = "green",
- is = "dead",
+ is = "unreachable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -325,7 +325,7 @@
name = "ashes",
descname = _ "Ashes",
editor_category = "wasteland",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 5,
@@ -341,7 +341,7 @@
name = "ashes2",
descname = _ "Ashes",
editor_category = "wasteland",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 4,
@@ -357,7 +357,7 @@
name = "hardground1",
descname = _ "Hard Ground",
editor_category = "wasteland",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -373,7 +373,7 @@
name = "hardground2",
descname = _ "Hard Ground",
editor_category = "wasteland",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -389,7 +389,7 @@
name = "hardground3",
descname = _ "Hard Ground",
editor_category = "wasteland",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -405,7 +405,7 @@
name = "hardground4",
descname = _ "Hard Ground",
editor_category = "wasteland",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -421,7 +421,7 @@
name = "hardlava",
descname = _ "Igneous Rocks",
editor_category = "wasteland",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "",
default_resource_amount = 0,
@@ -437,7 +437,7 @@
name = "wasteland_mountain1",
descname = _ "Mountain",
editor_category = "wasteland",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -453,7 +453,7 @@
name = "wasteland_mountain2",
descname = _ "Mountain",
editor_category = "wasteland",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -469,7 +469,7 @@
name = "wasteland_mountain3",
descname = _ "Mountain",
editor_category = "wasteland",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -485,7 +485,7 @@
name = "wasteland_mountain4",
descname = _ "Mountain",
editor_category = "wasteland",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -501,7 +501,7 @@
name = "wasteland_beach",
descname = _ "Beach",
editor_category = "wasteland",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -517,7 +517,7 @@
name = "lava-stone1",
descname = _ "Lava Rocks",
editor_category = "wasteland",
- is = "dead",
+ is = "unreachable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -534,7 +534,7 @@
name = "lava-stone2",
descname = _ "Lava Rocks",
editor_category = "wasteland",
- is = "dead",
+ is = "unreachable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -573,7 +573,7 @@
name = "tundra",
descname = _ "Tundra",
editor_category = "winter",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -589,7 +589,7 @@
name = "tundra2",
descname = _ "Tundra",
editor_category = "winter",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -605,7 +605,7 @@
name = "tundra3",
descname = _ "Tundra",
editor_category = "winter",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -621,7 +621,7 @@
name = "tundra_taiga",
descname = _ "Tundra Taiga",
editor_category = "winter",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -637,7 +637,7 @@
name = "taiga",
descname = _ "Taiga",
editor_category = "winter",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "water",
default_resource_amount = 10,
@@ -653,7 +653,7 @@
name = "snow",
descname = _ "Snow",
editor_category = "winter",
- is = "green",
+ is = "arable",
valid_resources = { "water" },
default_resource = "",
default_resource_amount = 0,
@@ -669,7 +669,7 @@
name = "winter_mountain1",
descname = _ "Mountain",
editor_category = "winter",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -685,7 +685,7 @@
name = "winter_mountain2",
descname = _ "Mountain",
editor_category = "winter",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -701,7 +701,7 @@
name = "winter_mountain3",
descname = _ "Mountain",
editor_category = "winter",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -717,7 +717,7 @@
name = "winter_mountain4",
descname = _ "Mountain",
editor_category = "winter",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -733,7 +733,7 @@
name = "ice",
descname = _ "Ice",
editor_category = "winter",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -749,7 +749,7 @@
name = "winter_beach",
descname = _ "Beach",
editor_category = "winter",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -821,7 +821,7 @@
name = "desert4",
descname = _ "Desert",
editor_category = "desert",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 2,
@@ -837,7 +837,7 @@
name = "drysoil",
descname = _ "Dry Soil",
editor_category = "desert",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 4,
@@ -851,7 +851,7 @@
name = "desert_steppe",
descname = _ "Steppe",
editor_category = "desert",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 5,
@@ -867,7 +867,7 @@
name = "meadow",
descname = _ "Meadow",
editor_category = "desert",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "water",
default_resource_amount = 10,
@@ -883,7 +883,7 @@
name = "mountainmeadow",
descname = _ "Mountain Meadow",
editor_category = "desert",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "",
default_resource_amount = 0,
@@ -899,7 +899,7 @@
name = "highmountainmeadow",
descname = _ "High Mountain Meadow",
editor_category = "desert",
- is = "green",
+ is = "arable",
valid_resources = {"water"},
default_resource = "",
default_resource_amount = 0,
@@ -915,7 +915,7 @@
name = "mountain1",
descname = _ "Mountain",
editor_category = "desert",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -931,7 +931,7 @@
name = "mountain2",
descname = _ "Mountain",
editor_category = "desert",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -947,7 +947,7 @@
name = "mountain3",
descname = _ "Mountain",
editor_category = "desert",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -963,7 +963,7 @@
name = "mountain4",
descname = _ "Mountain",
editor_category = "desert",
- is = "mountain",
+ is = "mineable",
valid_resources = { "coal", "iron", "gold", "stones" },
default_resource = "",
default_resource_amount = 0,
@@ -979,7 +979,7 @@
name = "desert1",
descname = _ "Desert",
editor_category = "desert",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -995,7 +995,7 @@
name = "desert2",
descname = _ "Desert",
editor_category = "desert",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -1011,7 +1011,7 @@
name = "desert3",
descname = _ "Desert",
editor_category = "desert",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
@@ -1027,7 +1027,7 @@
name = "desert_beach",
descname = _ "Beach",
editor_category = "desert",
- is = "dry",
+ is = "walkable",
valid_resources = {},
default_resource = "",
default_resource_amount = 0,
Follow ups
-
[Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: noreply, 2015-12-10
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: GunChleoc, 2015-12-10
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: TiborB, 2015-12-10
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: GunChleoc, 2015-12-10
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: TiborB, 2015-12-10
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: TiborB, 2015-12-10
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: GunChleoc, 2015-12-06
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: kaputtnik, 2015-12-05
-
Re: [Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: GunChleoc, 2015-12-05
-
[Merge] lp:~widelands-dev/widelands/is_value_terms into lp:widelands
From: kaputtnik, 2015-12-05